==> statistic-3.0.zip: statistic/admin.php <==
<?php
include('global.php');

if(array_key_exists('Operation', $_GET)) $Operation = $_GET['Operation']; else $Operation = '';
switch($Operation)
{
  case 'Add':
    $Output = ShowAdd();  
    break;
  case 'Delete':
    $Output = ShowDelete();  
    break;
  case 'Edit':
    $Output = ShowEdit();  
    break;
  case 'RebuildCache':
    $Output = ShowRebuildCache();  
    break;
  default:
    $Output = ShowNone();  
}
ShowPage($Output);

function ShowNone()
{
  global $Database;
  $Table = array(
    'Header' => array('Nzev veliiny', 'Operace'),
    'Rows' => array(),
  );

  $Result = $Database->select('measure', '*', '1 ORDER BY Description');
  while($Measure = $Result->fetch_array())
  {
    array_push($Table['Rows'], array($Measure['Description'], MakeLink('?Operation=Edit&amp;MeasureId='.$Measure['Id'], 'Editovat').' '.MakeLink('?Operation=Delete&amp;MeasureId='.$Measure['Id'], 'Odstranit').' '.MakeLink('?Operation=RebuildCache&amp;MeasureId='.$Measure['Id'], 'Pestavt cache')));
  }
  $Output = '<h3>Seznam men</h3>'.Table($Table).MakeLink('?Operation=Add', 'Pidat');
  return($Output); 
}

function ShowEdit()
{
  global $Database;
  $DbResult = $Database->select('measure', '*', 'Id='.addslashes($_GET['MeasureId']));
  $Values = array();
  $Values = $DbResult->fetch_array();
  return(ShowEditTable('Measure', $Values));
}

function ShowAdd()
{
  global $Database;
  $Values = array();
  return(ShowEditTable('Measure', $Values));
}

function ShowRebuildCache()
{
  global $Database;
  echo("Vytvam novou cache...<br>");
  $DbResult = $Database->select('measure', '*', 'Id='.addslashes($_GET['MeasureId']));
  $Measure = $DbResult->fetch_array();

  RebuildMeasureCache($Measure);  
  echo('Dokoneno<br>');         
}

?>

==> statistic-3.1.zip: statistic/admin.php <==
<?php
include('global.php');

if(array_key_exists('Operation', $_GET)) $Operation = $_GET['Operation']; else $Operation = '';
switch($Operation)
{
  case 'Add':
    $Output = ShowAdd();  
    break;
  case 'Delete':
    $Output = ShowDelete();  
    break;
  case 'Edit':
    $Output = ShowEdit();  
    break;
  case 'RebuildCache':
    $Output = ShowRebuildCache();  
    break;
  default:
    $Output = ShowNone();  
}
ShowPage($Output);

function ShowNone()
{
  global $Database;
  $Table = array(
    'Header' => array('Název veličiny', 'Operace'),
    'Rows' => array(),
  );

  $Result = $Database->select('measure', '*', '1 ORDER BY Description');
  while($Measure = $Result->fetch_array())
  {
    array_push($Table['Rows'], array($Measure['Description'], MakeLink('?Operation=Edit&amp;MeasureId='.$Measure['Id'], 'Editovat').' '.MakeLink('?Operation=Delete&amp;MeasureId='.$Measure['Id'], 'Odstranit').' '.MakeLink('?Operation=RebuildCache&amp;MeasureId='.$Measure['Id'], 'Přestavět cache')));
  }
  $Output = '<h3>Seznam měření</h3>'.Table($Table).MakeLink('?Operation=Add', 'Přidat');
  return($Output); 
}

function ShowEdit()
{
  global $Database;
  $DbResult = $Database->select('measure', '*', 'Id='.addslashes($_GET['MeasureId']));
  $Values = array();
  $Values = $DbResult->fetch_array();
  return(ShowEditTable('Measure', $Values));
}

function ShowAdd()
{
  global $Database;
  $Values = array();
  return(ShowEditTable('Measure', $Values));
}

function ShowRebuildCache()
{
  global $Database;
  echo("Vytvařím novou cache...<br>");
  $DbResult = $Database->select('measure', '*', 'Id='.addslashes($_GET['MeasureId']));
  $Measure = $DbResult->fetch_array();

  RebuildMeasureCache($Measure);  
  echo('Dokončeno<br>');         
}

?>
